# Description

We evaluate five text-to-SQL approaches (SQLNet, RatSQL, LGESQL, SmBoP, T5 + PICARD) regarding their applicability and utility in satisfying SE information needs. Therefore, we perform three experiments. Our experiments are based on two publicly available text-to-SQL datasets (Spider [2] and SEOSS-Queries [7]).

Experiment 1 aims to evaluate how well the standard large-scale cross-domain Spider dataset [2] is suited to train the examined text-to-SQL approaches when satisfying SE information needs, i.e., we used Spider for training and SEOSS-Queries' utterance-based split for evaluation. Experiment 2 and Experiment 3 aim to evaluate how the examined text-to-SQL approaches perform when trained and tested on software engineering data, i.e., using the SEOSS-Queries dataset [7] for training and evaluation.
In Experiment 2, we used the utterance-based split that had all queries already in the training and tested novel utterances for them, while in Experiment 3 by using the query-based split exposed the model at evaluation to queries not seen in the.

## Reproduction steps per text-to-SQL approach

### SQLNet

1. From [1] download the modified SQLNet Baseline version

2. Install the necessary requirements and download the the Spider dataset and the pretrained Glove word embedding as described in [1]

3. Copy the apache-pig folder from **SEOSS\_Queries\_orchestrated/Database and DB schema in sqlnet/data**. Replace **dev.json**, **train_others.json**(only for experiment 2 and experiment 3 relevant), and tables.json from **sqlnet/data/** with the ones provided in reproduction/Experiment_X/SQLNet/training_and_evaluation_step

4. To start training run the command below provided in [1]:

	```
	python train.py --dataset data/
	```

5. To generate predicted SQLs run the command below as in [1]:

	```
	python test.py --dataset data/ --output predicted_sql.txt

	```

6. Extract the predicted SQL queries only for the Apache Pig DB from the generated by the model SQL predictions file. By using the python script provided in [3] we evaluated the predicted SQL queries and an exact match accuracy was computed. To compute the exact match accuracy a gold (ground-truth) and predicted file as well as the table information only for the Apache Pig DB is needed. The ground-truth SQLs can be found in reproduction/experiment\_x/SQLNet/evaluation\_results/gold\_files for the respective experiment. Table information only for the Apache Pig DB can be found in reproduction/experiment\_x/SQLNet/evaluation\_results/ for the respective experiment. 
Additionally, in reproduction/experiment\_x/SQLNet/evaluation\_results/prediction\_files we provide the predicted SQLs, generated from our experiments that are described in our manuscript.

### RATSQL

1. From [4] download RatSQL 

2. Follow the instructions in [4] and download the Spider dataset [2], place it then in the directory **rat-sql-master** in a directory called **data** and build and run the docker image

3. Replace  **spider-glove-run.jsonnet** with the one provided in reproduction\experiment_x\RatSQL

4. Copy the **apache-pig** directory from **SEOSS\_Queries\_orchestrated/Database and DB schema** in **rat-sql-master/data/spider/database** 

5. Depending on the experiment you would like to reproduce replace **dev.json**, **train\_others.json**(only for experiment 2 and experiment 3 relevant), and **tables.json** from **rat-sql-master/data/spider** with the ones provided for the specific experiment in the folder **training_and_evaluation_step/**

6. To start training run the commands below as as in [4]:

	```
	python run.py preprocess experiments/spider-glove-run.jsonnet
	python run.py train experiments/spider-glove-run.jsonnet

	```
7. To generate predicted SQL queries run the command below as in [4]:

	```
	python run.py eval experiments/spider-glove-run.jsonnet
	```

8. RatSQL generated .eval-file from which we extracted the predicted SQL queries of only the Apache Pig DB. By using the python script provided in [3] we evaluated the predicted SQL queries and an exact match accuracy was computed. To compute the exact match accuracy a gold (ground-truth) and predicted file as well as the table information only for the Apache Pig DB is needed. The ground-truth SQLs can be found in reproduction/experiment\_x/RatSQL/evaluation\_results/gold\_files for the respective experiment. Table information only for the Apache Pig DB can be found in reproduction/experiment\_x/RatSQL/evaluation\_results/ for the respective Experiment. 
Additionally, in reproduction/experiment\_x/RatSQL/evaluation\_results/prediction\_files we provide the predicted SQLs, generated from our experiments that are described in our manuscript.

To compute exact match accuracy run the command below as described in [3].

    ```
    python3 evaluation.py --gold [gold file]  --pred [predicted file]  --etype match  --db [database dir] --table [table file]
	```

### LGESQL


The training and evaluation for LGESQL Glove msde was performed following the steps in [5]. Deviations from the steps in [5] are address below:

1. We created a conda environment, dowloaded the necessary dependencies, and pulled the vocab file for the Glove word embedding as described in [5].

2. After dowloading the spider dataset, and renaming it (provided as download in [5]) into the directory data, we performed the following steps:

	- Add the apache-pig DB from **SEOSS\_Queries\_orchestrated/Database and DB schema** into the directory database

	- To reproduce Experiment 1: 
		Merged version of train_spider.json and train_others.json into train.json
		Replace data/dev_spider.json with dev.json (merged version of dev_spider.json and SEOSS-Queries utterance-based test split json) provided in reproduction\experiment_1\LGESQL\training_and_evaluation_step\dev_spider_plus_pig
		Replace dataset/tables.json with the one from  reproduction\experiment_1\LGESQL\training_and_evaluation_step
        
    - To reproduce Experiment 2: 
		Replace data/train_spider.json and data/train_others.json with train.json (merged version of train_spider.json, train_others.json, and SEOSS-Queries utterance-based train split json) provided in reproduction/experiment\_2/LGESQL/training\_and\_evaluation\_step
		Replace data/dev_spider.json with dev.json (merged version of dev_spider.json and SEOSS-Queries utterance-based test split json) provided in reproduction/experiment\_2/LGESQL/training\_and\_evaluation\_step/dev\_spider\_plus\_pig
		Replace dataset/tables.json with reproduction/experiment\_2/LGESQL/training\_and\_evaluation\_step
        
	- To reproduce Experiment 3: 
		Replace data/train_spider.json and data/train_others.json with train.json (merged version of train_spider.json, train_others.json, and SEOSS-Queries query-based train split) provided in reproduction/experiment\_3/LGESQL/training\_and\_evaluation\_step
		Replace data/dev_spider.json with dev.json (merged version of dev_spider.json and SEOSS-Queries query-based test split json) provided in reproduction/experiment\_3/LGESQL/training\_and\_evaluation\_step/dev\_spider\_plus\_pig
		Replace dataset/tables.json with reproduction/experiment\_3/LGESQL/training\_and\_evaluation\_step
		
3. Preprocess the train and dev dataset via the following command as in [5]:

	```
	./run/run_preprocessing.sh
	```

5. Train LGESQL via the following command as in [5]:

	```
	./run/run_lgesql_glove.sh [msde]
	```

6. Create the directory saved_models, save the trained model and its configuration into the directory as described in [5]

7. Run the following command to generate the predictions as in [5]:

    ```
    run/run_evaluation.sh
	```

8. Extract the predicted SQL queries only for the Apache Pig DB from the generated by the model SQL predictions file. By using the python script provided in [3] we evaluated the predicted SQL queries and an exact match accuracy was computed. To compute the exact match accuracy a gold (ground-truth) and predicted file as well as the table information only for the Apache Pig DB is needed. The ground-truth SQLs can be found in reproduction/experiment\_x/LGESQL/evaluation\_results/gold\_files for the respective experiment. Table information only for the Apache Pig DB can be found in reproduction/experiment\_x/LGESQL/evaluation\_results/ for the respective Experiment. 
Additionally, in reproduction/experiment\_x/LGESQL/evaluation\_results/prediction\_files we provide the predicted SQLs, generated from our experiments that are described in our manuscript.


### SmBoP 


The training and evaluation for SmBoP was performed following the steps in [6]. Deviations from the steps in [6] are address below:

1. Install the necessary versions for python and CUDA, and package requirements as described in [6].

2. Download the Spider dataset [2] by running the following command as in [6]:

    ```
    bash scripts/download_spider.sh
    ```  

3. Prepare the training and evaluation datasets as follows:

	- Add the apache-pig directory provided in **SEOSS\_Queries\_orchestrated/Database and DB schema**  into the directory dataset/database

	- To reproduce Experiment 1: 
		Replace dataset/dev.json with dev.json (merged version of dev_spider.json and SEOSS-Queries utterance-based test 	split json) provided in reproduction/experiment\_1/SmBoP/training\_and\_evaluation\_step
		Replace dataset/tables.json with the one in reproduction/experiment\_1/SmBoP/training\_and\_evaluation\_step
        
	- To reproduce Experiment 2: 
		Replace dataset/train_spider.json with train.json (merged version of train\_spider.json and SEOSS-Queries 	utterance-based train split) provided in reproduction/experiment\_2\SmBoP\training_and_evaluation_step
		Replace data/dev_spider.json with dev.json (merged version of dev_spider.json and SEOSS-Queries utterance-based 	test split json) provided in reproduction/experiment\_2/SmBoP/training\_and\_evaluation\_step
		Replace dataset/tables.json with Experiment1/SmBoP/Training/tables.json
        
	- To reproduce Experiment 3: 
		Replace dataset/train\_spider.json with train\_spider.json (merged version of train_spider.json, and SEOSS-		Queries query-based train split) provided in reproduction/experiment\_3/SmBoP/training\_and\_evaluation\_step
		Replace dataset/dev\_spider.json with dev.json (merged version of dev_spider.json and SEOSS-Queries query-based 	test split json) provided in reproduction/experiment\_3/SmBoP/training\_and\_evaluation\_step
		Replace dataset/tables.json with the one in reproduction/experiment\_2/SmBoP/training\_and\_evaluation\_step

4. To start traing run the command as described in [6]:

	```
	python exec.py
	```

5. Extract the predicted SQL queries only for the Apache Pig DB from the generated by the model SQL predictions file. By using the python script provided in [3] we evaluated the predicted SQL queries and an exact match accuracy was computed. To compute the exact match accuracy a gold (ground-truth) and predicted file as well as the table information only for the Apache Pig DB is needed. The ground-truth SQLs can be found in reproduction/experiment\_x/SmBoP/evaluation\_results/gold\_files for the respective experiment. Table information only for the Apache Pig DB can be found in reproduction/experiment\_x/SmBoP/evaluation\_results/ for the respective Experiment. 
Additionally, in reproduction/experiment\_x/SmBoP/evaluation\_results/prediction\_files we provide the predicted SQLs, generated from our experiments that are described in our manuscript.



**Sources**

[1] - https://github.com/taoyds/spider/tree/master/baselines/sqlnet

[2] - https://github.com/taoyds/spider

[3] - https://github.com/taoyds/test-suite-sql-eval

[4] - https://github.com/microsoft/rat-sql

[5] - https://github.com/rhythmcao/text2sql-lgesql

[6] - https://github.com/OhadRubin/SmBop

[7] - Tomova, Mihaela & Hofmann, Martin & Mäder, Patrick. (2022). SEOSS-Queries - a Software Engineering Dataset for Text-to-SQL and Question Answering Tasks. Data in Brief. 42. 108211. 10.1016/j.dib.2022.108211.