PRAGMA foreign_keys = ON;
CREATE TABLE IF NOT EXISTS "issue_fix_version" (
	"issue_id"	text NOT NULL,
	"fix_version"	text NOT NULL,
	FOREIGN KEY("issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "issue_component" (
	"issue_id"	text NOT NULL,
	"component"	text NOT NULL,
	FOREIGN KEY("issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "issue_comment" (
	"issue_id"	text NOT NULL,
	"username"	text,
	"display_name"	text,
	"created_date"	text,
	"created_date_zoned"	text,
	"message"	text,
	FOREIGN KEY("issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "issue_changelog" (
	"issue_id"	text NOT NULL,
	"username"	text,
	"display_name"	text,
	"created_date"	text,
	"created_date_zoned"	text,
	"group_id"	integer,
	"field_type"	text,
	"field"	text,
	"from_value"	text,
	"from_string"	text,
	"to_value"	text,
	"to_string"	text,
	FOREIGN KEY("issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "issue_attachment" (
	"issue_id"	text NOT NULL,
	"username"	text,
	"display_name"	text,
	"created_date"	text,
	"created_date_zoned"	text,
	"mime_type"	text,
	"content"	text,
	"filename"	text,
	"size_bytes"	integer,
	FOREIGN KEY("issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "issue" (
	"issue_id"	text NOT NULL UNIQUE,
	"type"	text,
	"created_date"	text,
	"created_date_zoned"	text,
	"updated_date"	text,
	"updated_date_zoned"	text,
	"resolved_date"	text,
	"resolved_date_zoned"	text,
	"summary"	text,
	"description"	text,
	"priority"	text,
	"status"	text,
	"resolution"	text,
	"assignee"	text,
	"assignee_username"	text,
	"reporter"	text,
	"reporter_username"	text,
	PRIMARY KEY("issue_id")
);
CREATE TABLE IF NOT EXISTS "code_change" (
	"commit_hash"	text NOT NULL,
	"file_path"	text,
	"old_file_path"	text,
	"change_type"	text,
	"patch_type"	text,
	"is_deleted"	integer,
	"sum_added_lines"	integer,
	"sum_removed_lines"	integer,
	FOREIGN KEY("commit_hash") REFERENCES "change_set"("commit_hash")
);
CREATE TABLE IF NOT EXISTS "change_set_link" (
	"commit_hash"	text NOT NULL,
	"issue_id"	text NOT NULL,
	FOREIGN KEY("commit_hash") REFERENCES "change_set"("commit_hash"),
	FOREIGN KEY("issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "change_set" (
	"commit_hash"	text NOT NULL UNIQUE,
	"git_repository_id"	integer,
	"committed_date"	text,
	"committed_date_zoned"	text,
	"message"	text,
	"author"	text,
	"author_email"	text,
	"is_merge"	integer,
	PRIMARY KEY("commit_hash")
);
CREATE TABLE IF NOT EXISTS "meta" (
	"key"	text NOT NULL UNIQUE,
	"value"	text NOT NULL
);
CREATE TABLE IF NOT EXISTS "git_repository" (
	"git_repository_id"	integer NOT NULL UNIQUE,
	"name"	text NOT NULL,
	"url"	text NOT NULL,
	"checkout_hash"	text NOT NULL
);
CREATE TABLE "issue_link" (
	"source_issue_id"	text NOT NULL,
	"target_issue_id"	text NOT NULL,
	"name"	text,
	"outward_label"	text,
	"is_containment"	integer,
	FOREIGN KEY("source_issue_id") REFERENCES "issue"("issue_id"),
	FOREIGN KEY("target_issue_id") REFERENCES "issue"("issue_id")
);
CREATE TABLE IF NOT EXISTS "jira_repository" (
	"key"	text NOT NULL UNIQUE,
	"base_url"	text NOT NULL
);
COMMIT;
